@@ -117,15 +117,15 @@ void Options2::retrievePushButton_clicked()
     d->setType( "amarok/theme" );
     // you have to do this by hand when providing your own Engine
     KNS::ProviderLoader *p = new KNS::ProviderLoader( this );
-    connect( p, TQT_SIGNAL( providersLoaded(Provider::List*) ), d, TQT_SLOT( slotProviders(Provider::List *) ) );
+    connect( p, TQ_SIGNAL( providersLoaded(Provider::List*) ), d, TQ_SLOT( slotProviders(Provider::List *) ) );
     p->load( "amarok theme", "https://www.trinitydesktop.org/ocs/providers.xml" );
 
-    connect( d, TQT_SIGNAL( finished() ), d, TQT_SLOT( delayedDestruct() ) );
-    connect( d, TQT_SIGNAL( finished() ), this, TQT_SLOT( updateStyleComboBox() ) );
+    connect( d, TQ_SIGNAL( finished() ), d, TQ_SLOT( delayedDestruct() ) );
+    connect( d, TQ_SIGNAL( finished() ), this, TQ_SLOT( updateStyleComboBox() ) );
 
     // Due to tdelibs idiocy, KNS::DownloadDialog is /always/ non-modal. So we have to
     // ensure that closing the settings dialog before the DownloadDialog doesn't crash.
-    TQTimer::singleShot( 0, d, TQT_SLOT( exec() ) );
+    TQTimer::singleShot( 0, d, TQ_SLOT( exec() ) );
 }
 
 
