@@ -197,7 +197,7 @@ App::App()
     AEInstallEventHandler(kCoreEventClass, kAEReopenApplication, appleEventProcessorUPP, (long)this, true);
 #endif
 
-    TQTimer::singleShot( 0, this, TQT_SLOT( continueInit() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( continueInit() ) );
 }
 
 App::~App()
@@ -434,48 +434,48 @@ void App::initGlobalShortcuts()
     EngineController* const ec = EngineController::instance();
 
     m_pGlobalAccel->insert( "play", i18n( "Play" ), 0, KKey("WIN+x"), 0,
-                            ec, TQT_SLOT( play() ), true, true );
+                            ec, TQ_SLOT( play() ), true, true );
     m_pGlobalAccel->insert( "pause", i18n( "Pause" ), 0, 0, 0,
-                            ec, TQT_SLOT( pause() ), true, true );
+                            ec, TQ_SLOT( pause() ), true, true );
     m_pGlobalAccel->insert( "play_pause", i18n( "Play/Pause" ), 0, KKey("WIN+c"), 0,
-                            ec, TQT_SLOT( playPause() ), true, true );
+                            ec, TQ_SLOT( playPause() ), true, true );
     m_pGlobalAccel->insert( "stop", i18n( "Stop" ), 0, KKey("WIN+v"), 0,
-                            ec, TQT_SLOT( stop() ), true, true );
+                            ec, TQ_SLOT( stop() ), true, true );
     m_pGlobalAccel->insert( "stop_after_global", i18n( "Stop Playing After Current Track" ), 0, KKey("WIN+CTRL+v"), 0,
-                            TQT_TQOBJECT(Playlist::instance()->qscrollview()), TQT_SLOT( toggleStopAfterCurrentTrack() ), true, true );
+                            Playlist::instance()->qscrollview(), TQ_SLOT( toggleStopAfterCurrentTrack() ), true, true );
     m_pGlobalAccel->insert( "next", i18n( "Next Track" ), 0, KKey("WIN+b"), 0,
-                            ec, TQT_SLOT( next() ), true, true );
+                            ec, TQ_SLOT( next() ), true, true );
     m_pGlobalAccel->insert( "prev", i18n( "Previous Track" ), 0, KKey("WIN+z"), 0,
-                            ec, TQT_SLOT( previous() ), true, true );
+                            ec, TQ_SLOT( previous() ), true, true );
     m_pGlobalAccel->insert( "volup", i18n( "Increase Volume" ), 0, KKey("WIN+KP_Add"), 0,
-                            ec, TQT_SLOT( increaseVolume() ), true, true );
+                            ec, TQ_SLOT( increaseVolume() ), true, true );
     m_pGlobalAccel->insert( "voldn", i18n( "Decrease Volume" ), 0, KKey("WIN+KP_Subtract"), 0,
-                            ec, TQT_SLOT( decreaseVolume() ), true, true );
+                            ec, TQ_SLOT( decreaseVolume() ), true, true );
     m_pGlobalAccel->insert( "seekforward", i18n( "Seek Forward" ), 0, KKey("WIN+Shift+KP_Add"), 0,
-                            ec, TQT_SLOT( seekForward() ), true, true );
+                            ec, TQ_SLOT( seekForward() ), true, true );
     m_pGlobalAccel->insert( "seekbackward", i18n( "Seek Backward" ), 0, KKey("WIN+Shift+KP_Subtract"), 0,
-                            ec, TQT_SLOT( seekBackward() ), true, true );
+                            ec, TQ_SLOT( seekBackward() ), true, true );
     m_pGlobalAccel->insert( "playlist_add", i18n( "Add Media..." ), 0, KKey("WIN+a"), 0,
-                            TQT_TQOBJECT(m_pPlaylistWindow), TQT_SLOT( slotAddLocation() ), true, true );
+                            m_pPlaylistWindow, TQ_SLOT( slotAddLocation() ), true, true );
     m_pGlobalAccel->insert( "show", i18n( "Toggle Playlist Window" ), 0, KKey("WIN+p"), 0,
-                            TQT_TQOBJECT(m_pPlaylistWindow), TQT_SLOT( showHide() ), true, true );
+                            m_pPlaylistWindow, TQ_SLOT( showHide() ), true, true );
 #ifdef TQ_WS_X11
     m_pGlobalAccel->insert( "osd", i18n( "Show OSD" ), 0, KKey("WIN+o"), 0,
-                            TQT_TQOBJECT(Amarok::OSD::instance()), TQT_SLOT( forceToggleOSD() ), true, true );
+                            Amarok::OSD::instance(), TQ_SLOT( forceToggleOSD() ), true, true );
 #endif
     m_pGlobalAccel->insert( "mute", i18n( "Mute Volume" ), 0, KKey("WIN+m"), 0,
-                            ec, TQT_SLOT( mute() ), true, true );
+                            ec, TQ_SLOT( mute() ), true, true );
 
     m_pGlobalAccel->insert( "rating1", i18n( "Rate Current Track: 1" ), 0, KKey("WIN+1"), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( setRating1() ), true, true );
+                            this, TQ_SLOT( setRating1() ), true, true );
     m_pGlobalAccel->insert( "rating2", i18n( "Rate Current Track: 2" ), 0, KKey("WIN+2"), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( setRating2() ), true, true );
+                            this, TQ_SLOT( setRating2() ), true, true );
     m_pGlobalAccel->insert( "rating3", i18n( "Rate Current Track: 3" ), 0, KKey("WIN+3"), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( setRating3() ), true, true );
+                            this, TQ_SLOT( setRating3() ), true, true );
     m_pGlobalAccel->insert( "rating4", i18n( "Rate Current Track: 4" ), 0, KKey("WIN+4"), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( setRating4() ), true, true );
+                            this, TQ_SLOT( setRating4() ), true, true );
     m_pGlobalAccel->insert( "rating5", i18n( "Rate Current Track: 5" ), 0, KKey("WIN+5"), 0,
-                            TQT_TQOBJECT(this), TQT_SLOT( setRating5() ), true, true );
+                            this, TQ_SLOT( setRating5() ), true, true );
 
     m_pGlobalAccel->setConfigGroup( "Shortcuts" );
     m_pGlobalAccel->readSettings( kapp->config() );
@@ -540,12 +540,12 @@ void App::fixHyperThreading()
         #endif //SCHEDAFFINITY_3PARAMS
         {
             warning() << "sched_setaffinity() call failed with error code: " << errno << endl;
-            TQTimer::singleShot( 0, this, TQT_SLOT( showHyperThreadingWarning() ) );
+            TQTimer::singleShot( 0, this, TQ_SLOT( showHyperThreadingWarning() ) );
             return;
         }
         #else //SCHEDAFFINITY_SUPPORT
              warning()<<"glibc failed checks for sched_setaffinity" << endl;
-        TQTimer::singleShot( 0, this, TQT_SLOT( showHyperThreadingWarning() ) );
+        TQTimer::singleShot( 0, this, TQ_SLOT( showHyperThreadingWarning() ) );
         #endif //SCHEDAFFINITY_SUPPORT
     }
     else { debug() << "Workaround not enabled" << endl; }
@@ -641,7 +641,7 @@ void App::applySettings( bool firstTime )
             if( !firstTime ) m_pPlayerWindow->show();
 
 
-            connect( m_pPlayerWindow, TQT_SIGNAL(playlistToggled( bool )), m_pPlaylistWindow, TQT_SLOT(showHide()) );
+            connect( m_pPlayerWindow, TQ_SIGNAL(playlistToggled( bool )), m_pPlaylistWindow, TQ_SLOT(showHide()) );
 
 #ifdef TQ_WS_X11
             //TODO get this to work!
@@ -779,14 +779,14 @@ App::continueInit()
     CollectionDB::instance()->checkDatabase();
 
     m_pMediaDeviceManager = MediaDeviceManager::instance();
-    m_pGlobalAccel    = new TDEGlobalAccel( TQT_TQOBJECT(this) );
+    m_pGlobalAccel    = new TDEGlobalAccel( this );
     m_pPlaylistWindow = new PlaylistWindow();
 #ifdef TQ_WS_X11
     m_pTray           = new Amarok::TrayIcon( m_pPlaylistWindow );
 #endif
     m_pPlaylistWindow->init(); //creates the playlist, browsers, etc.
     //init playlist window as soon as the database is guaranteed to be usable
-    //connect( CollectionDB::instance(), TQT_SIGNAL( databaseUpdateDone() ), m_pPlaylistWindow, TQT_SLOT( init() ) );
+    //connect( CollectionDB::instance(), TQ_SIGNAL( databaseUpdateDone() ), m_pPlaylistWindow, TQ_SLOT( init() ) );
     initGlobalShortcuts();
     //load previous playlist in separate thread
     if ( restoreSession && AmarokConfig::savePlaylist() )
@@ -837,11 +837,11 @@ App::continueInit()
     // (e.g. deleted collection.db)
     if ( CollectionDB::instance()->isEmpty() )
     {
-         //connect( collDB, TQT_SIGNAL( databaseUpdateDone() ), collDB, TQT_SLOT( startScan() ) );
+         //connect( collDB, TQ_SIGNAL( databaseUpdateDone() ), collDB, TQ_SLOT( startScan() ) );
         collDB->startScan();
     }
     else if ( AmarokConfig::monitorChanges() )
-        //connect( collDB, TQT_SIGNAL( databaseUpdateDone() ), collDB, TQT_SLOT( scanModifiedDirs() ) );
+        //connect( collDB, TQ_SIGNAL( databaseUpdateDone() ), collDB, TQ_SLOT( scanModifiedDirs() ) );
         collDB->scanModifiedDirs();
 
 
@@ -854,8 +854,8 @@ App::applyColorScheme()
     TQColorGroup group;
     using Amarok::ColorScheme::AltBase;
     int h, s, v;
-    TQWidget* const browserBar = TQT_TQWIDGET( playlistWindow()->child( "BrowserBar" ) );
-    TQWidget* const contextBrowser = TQT_TQWIDGET( ContextBrowser::instance() );
+    TQWidget* const browserBar = static_cast<TQWidget*>( playlistWindow()->child( "BrowserBar" ) );
+    TQWidget* const contextBrowser = ContextBrowser::instance();
 
     if( AmarokConfig::schemeKDE() )
     {
@@ -951,7 +951,7 @@ App::applyColorScheme()
     // set the TDEListView alternate colours
     TQObjectList* const list = playlistWindow()->queryList( "TDEListView" );
     for( TQObject *o = list->first(); o; o = list->next() )
-        static_cast<TDEListView*>(TQT_TQWIDGET(o))->setAlternateBackground( AltBase );
+        static_cast<TDEListView*>(o)->setAlternateBackground( AltBase );
     delete list; //heap allocated!
 }
 
@@ -1008,7 +1008,7 @@ bool Amarok::genericEventHandler( TQWidget *recipient, TQEvent *e )
     //please don't remove!
     case TQEvent::Wheel:
     {
-        #define e TQT_TQWHEELEVENT(e)
+        #define e static_cast<TQWheelEvent*>(e)
 
         //this behaviour happens for the systray and the player window
         //to override one, override it in that class
@@ -1045,7 +1045,7 @@ bool Amarok::genericEventHandler( TQWidget *recipient, TQEvent *e )
         //KDE policy states we should hide to tray and not quit() when the
         //close window button is pushed for the main widget
 
-        TQT_TQCLOSEEVENT(e)->accept(); //if we don't do this the info box appears on quit()!
+        static_cast<TQCloseEvent*>(e)->accept(); //if we don't do this the info box appears on quit()!
 
         if( AmarokConfig::showTrayIcon() && !e->spontaneous() && !kapp->sessionSaving() )
         {
@@ -1138,7 +1138,7 @@ void App::slotConfigAmarok( const TQCString& page )
         //TDEConfigDialog didn't find an instance of this dialog, so lets create it :
         dialog = new AmarokConfigDialog( m_pPlaylistWindow, "settings", AmarokConfig::self() );
 
-        connect( dialog, TQT_SIGNAL(settingsChanged()), TQT_SLOT(applySettings()) );
+        connect( dialog, TQ_SIGNAL(settingsChanged()), TQ_SLOT(applySettings()) );
     }
 
     //FIXME it seems that if the dialog is on a different desktop it gets lost
@@ -1187,7 +1187,7 @@ void App::firstRunWizard()
     setTopWidget( &wizard );
     TDEConfigDialogManager* config = new TDEConfigDialogManager(&wizard, AmarokConfig::self(), "wizardconfig");
     config->updateWidgets();
-   // connect(config, TQT_SIGNAL(settingsChanged()), TQT_SLOT(updateSettings()));
+   // connect(config, TQ_SIGNAL(settingsChanged()), TQ_SLOT(updateSettings()));
     wizard.setCaption( makeStdCaption( i18n( "First-Run Wizard" ) ) );
 
     if( wizard.exec() != TQDialog::Rejected )
@@ -1234,7 +1234,7 @@ TDEIO::Job *App::trashFiles( const KURL::List &files )
 #if KDE_IS_VERSION( 3, 3, 91 )
     TDEIO::Job *job = TDEIO::trash( files, true /*show progress*/ );
     Amarok::StatusBar::instance()->newProgressOperation( job ).setDescription( i18n("Moving files to trash") );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( slotTrashResult( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotTrashResult( TDEIO::Job* ) ) );
     return job;
 #else
     TDEIO::Job* job = TDEIO::move( files, TDEGlobalSettings::trashPath() );
@@ -1271,8 +1271,8 @@ void App::slotTrashResult( TDEIO::Job *job )
 
 TQWidget *App::mainWindow() const
 {
-    return AmarokConfig::showPlayerWindow() ? TQT_TQWIDGET( m_pPlayerWindow )
-                                            : TQT_TQWIDGET( m_pPlaylistWindow );
+    return AmarokConfig::showPlayerWindow() ? static_cast<TQWidget*>( m_pPlayerWindow )
+                                            : static_cast<TQWidget*>( m_pPlaylistWindow );
 }
 
 void App::quit()
@@ -1281,7 +1281,7 @@ void App::quit()
     if( MediaBrowser::instance()->blockQuit() )
     {
         // don't quit yet, as some media devices still have to finish transferring data
-        TQTimer::singleShot( 100, this, TQT_SLOT( quit() ) );
+        TQTimer::singleShot( 100, this, TQ_SLOT( quit() ) );
         return;
     }
     TDEApplication::quit();
