@@ -41,7 +41,7 @@ class MediaDeviceManager;
 
 class LIBAMAROK_EXPORT App : public TDEApplication, public EngineObserver
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         App();
