@@ -147,7 +147,7 @@ CoverManager::CoverManager()
         m_searchEdit->setFrame( TQFrame::Sunken );
 
         searchToolBar->setStretchableWidget( m_searchEdit );
-        connect( button, TQT_SIGNAL(clicked()), m_searchEdit, TQT_SLOT(clear()) );
+        connect( button, TQ_SIGNAL(clicked()), m_searchEdit, TQ_SLOT(clear()) );
 
         TQToolTip::add( button, i18n( "Clear search field" ) );
         TQToolTip::add( m_searchEdit, i18n( "Enter space-separated terms to search in the albums" ) );
@@ -161,7 +161,7 @@ CoverManager::CoverManager()
     m_viewMenu->insertItem( i18n("Albums With Cover"), AlbumsWithCover );
     m_viewMenu->insertItem( i18n("Albums Without Cover"), AlbumsWithoutCover );
     m_viewMenu->setItemChecked( AllAlbums, true );
-    connect( m_viewMenu, TQT_SIGNAL( activated(int) ), TQT_SLOT( changeView(int) ) );
+    connect( m_viewMenu, TQ_SIGNAL( activated(int) ), TQ_SLOT( changeView(int) ) );
 
     #ifdef AMAZON_SUPPORT
     // amazon locale menu
@@ -172,7 +172,7 @@ CoverManager::CoverManager()
     m_amazonLocaleMenu->insertItem( i18n("Germany"), CoverFetcher::Germany );
     m_amazonLocaleMenu->insertItem( i18n("Japan"), CoverFetcher::Japan);
     m_amazonLocaleMenu->insertItem( i18n("United Kingdom"), CoverFetcher::UK );
-    connect( m_amazonLocaleMenu, TQT_SIGNAL( activated(int) ), TQT_SLOT( changeLocale(int) ) );
+    connect( m_amazonLocaleMenu, TQ_SIGNAL( activated(int) ), TQ_SLOT( changeLocale(int) ) );
     #endif
 
     TDEToolBar* toolBar = new TDEToolBar( hbox );
@@ -188,7 +188,7 @@ CoverManager::CoverManager()
 
     //fetch missing covers button
     m_fetchButton = new KPushButton( KGuiItem( i18n("Fetch Missing Covers"), Amarok::icon( "download" ) ), hbox );
-    connect( m_fetchButton, TQT_SIGNAL(clicked()), TQT_SLOT(fetchMissingCovers()) );
+    connect( m_fetchButton, TQ_SIGNAL(clicked()), TQ_SLOT(fetchMissingCovers()) );
     #endif
 
     //cover view
@@ -200,7 +200,7 @@ CoverManager::CoverManager()
     m_statusLabel->setIndent( 3 );
     m_statusBar->addWidget( m_progressBox = new TQHBox( m_statusBar ), 1, true );
     KPushButton *stopButton = new KPushButton( KGuiItem(i18n("Abort"), "process-stop"), m_progressBox );
-    connect( stopButton, TQT_SIGNAL(clicked()), TQT_SLOT(stopFetching()) );
+    connect( stopButton, TQ_SIGNAL(clicked()), TQ_SLOT(stopFetching()) );
     m_progress = new KProgress( m_progressBox );
     m_progress->setCenterIndicator( true );
 
@@ -211,24 +211,24 @@ CoverManager::CoverManager()
 
 
     // signals and slots connections
-    connect( m_artistView, TQT_SIGNAL(selectionChanged( TQListViewItem* ) ),
-                           TQT_SLOT(slotArtistSelected( TQListViewItem* )) );
-    connect( m_coverView,  TQT_SIGNAL(contextMenuRequested( TQIconViewItem*, const TQPoint& )),
-                           TQT_SLOT(showCoverMenu( TQIconViewItem*, const TQPoint& )) );
-    connect( m_coverView,  TQT_SIGNAL(executed( TQIconViewItem* )),
-                           TQT_SLOT(coverItemExecuted( TQIconViewItem* )) );
-    connect( m_timer,      TQT_SIGNAL(timeout()),
-                           TQT_SLOT(slotSetFilter()) );
-    connect( m_searchEdit, TQT_SIGNAL(textChanged( const TQString& )),
-                           TQT_SLOT(slotSetFilterTimeout()) );
+    connect( m_artistView, TQ_SIGNAL(selectionChanged( TQListViewItem* ) ),
+                           TQ_SLOT(slotArtistSelected( TQListViewItem* )) );
+    connect( m_coverView,  TQ_SIGNAL(contextMenuRequested( TQIconViewItem*, const TQPoint& )),
+                           TQ_SLOT(showCoverMenu( TQIconViewItem*, const TQPoint& )) );
+    connect( m_coverView,  TQ_SIGNAL(executed( TQIconViewItem* )),
+                           TQ_SLOT(coverItemExecuted( TQIconViewItem* )) );
+    connect( m_timer,      TQ_SIGNAL(timeout()),
+                           TQ_SLOT(slotSetFilter()) );
+    connect( m_searchEdit, TQ_SIGNAL(textChanged( const TQString& )),
+                           TQ_SLOT(slotSetFilterTimeout()) );
 
     #ifdef AMAZON_SUPPORT
-    connect( CollectionDB::instance(), TQT_SIGNAL(coverFetched( const TQString&, const TQString& )),
-                                       TQT_SLOT(coverFetched( const TQString&, const TQString& )) );
-    connect( CollectionDB::instance(), TQT_SIGNAL(coverRemoved( const TQString&, const TQString& )),
-                                       TQT_SLOT(coverRemoved( const TQString&, const TQString& )) );
-    connect( CollectionDB::instance(), TQT_SIGNAL(coverFetcherError( const TQString& )),
-                                       TQT_SLOT(coverFetcherError()) );
+    connect( CollectionDB::instance(), TQ_SIGNAL(coverFetched( const TQString&, const TQString& )),
+                                       TQ_SLOT(coverFetched( const TQString&, const TQString& )) );
+    connect( CollectionDB::instance(), TQ_SIGNAL(coverRemoved( const TQString&, const TQString& )),
+                                       TQ_SLOT(coverRemoved( const TQString&, const TQString& )) );
+    connect( CollectionDB::instance(), TQ_SIGNAL(coverFetcherError( const TQString& )),
+                                       TQ_SLOT(coverFetcherError()) );
     #endif
 
     m_currentView = AllAlbums;
@@ -238,7 +238,7 @@ CoverManager::CoverManager()
 
     show();
 
-    TQTimer::singleShot( 0, this, TQT_SLOT(init()) );
+    TQTimer::singleShot( 0, this, TQ_SLOT(init()) );
 }
 
 
@@ -347,7 +347,7 @@ void CoverManager::fetchCoversLoop() //SLOT
         m_fetchCounter++;
 
         // Wait 1 second, since amazon caps the number of accesses per client
-        TQTimer::singleShot( 1000, this, TQT_SLOT( fetchCoversLoop() ) );
+        TQTimer::singleShot( 1000, this, TQ_SLOT( fetchCoversLoop() ) );
     }
     else {
         m_fetchCovers.clear();
@@ -809,7 +809,7 @@ void CoverManager::updateStatusBar()
             m_fetchingCovers = 0;
             m_coversFetched = 0;
             m_coverErrors = 0;
-            TQTimer::singleShot( 2000, this, TQT_SLOT( updateStatusBar() ) );
+            TQTimer::singleShot( 2000, this, TQ_SLOT( updateStatusBar() ) );
         }
 
         if( m_fetchingCovers == 1 ) {
@@ -900,8 +900,8 @@ CoverView::CoverView( TQWidget *parent, const char *name, WFlags f )
     // icon (and not the text), we have to create our own tooltips
     setShowToolTips( false );
 
-    connect( this, TQT_SIGNAL( onItem( TQIconViewItem * ) ), TQT_SLOT( setStatusText( TQIconViewItem * ) ) );
-    connect( this, TQT_SIGNAL( onViewport() ), CoverManager::instance(), TQT_SLOT( updateStatusBar() ) );
+    connect( this, TQ_SIGNAL( onItem( TQIconViewItem * ) ), TQ_SLOT( setStatusText( TQIconViewItem * ) ) );
+    connect( this, TQ_SIGNAL( onViewport() ), CoverManager::instance(), TQ_SLOT( updateStatusBar() ) );
 }
 
 
