@@ -95,8 +95,8 @@ CollectionDB::CollectionDB()
 
     startTimer( MONITOR_INTERVAL * 1000 );
 
-    connect( Scrobbler::instance(), TQT_SIGNAL( similarArtistsFetched( const TQString&, const TQStringList& ) ),
-             this,                  TQT_SLOT( similarArtistsFetched( const TQString&, const TQStringList& ) ) );
+    connect( Scrobbler::instance(), TQ_SIGNAL( similarArtistsFetched( const TQString&, const TQStringList& ) ),
+             this,                  TQ_SLOT( similarArtistsFetched( const TQString&, const TQStringList& ) ) );
 }
 
 
@@ -1514,7 +1514,7 @@ CollectionDB::setCompilation( const TQString &album, const bool enabled, const b
     // Update the Collection-Browser view,
     // using TQTimer to make sure we don't manipulate the GUI from a thread
     if ( updateView )
-        TQTimer::singleShot( 0, CollectionView::instance(), TQT_SLOT( renderView() ) );
+        TQTimer::singleShot( 0, CollectionView::instance(), TQ_SLOT( renderView() ) );
 }
 
 
@@ -1554,7 +1554,7 @@ CollectionDB::updateTags( const TQString &url, const MetaBundle &bundle, const b
     // Update the Collection-Browser view,
     // using TQTimer to make sure we don't manipulate the GUI from a thread
     if ( updateView )
-        TQTimer::singleShot( 0, CollectionView::instance(), TQT_SLOT( renderView() ) );
+        TQTimer::singleShot( 0, CollectionView::instance(), TQ_SLOT( renderView() ) );
 }
 
 
@@ -1681,7 +1681,7 @@ CollectionDB::fetchCover( TQWidget* parent, const TQString& artist, const TQStri
     debug() << "Fetching cover for " << artist << " - " << album << endl;
 
     CoverFetcher* fetcher = new CoverFetcher( parent, artist, album );
-    connect( fetcher, TQT_SIGNAL(result( CoverFetcher* )), TQT_SLOT(coverFetcherResult( CoverFetcher* )) );
+    connect( fetcher, TQ_SIGNAL(result( CoverFetcher* )), TQ_SLOT(coverFetcherResult( CoverFetcher* )) );
     fetcher->setUserCanEditQuery( !noedit );
     fetcher->startFetch();
     #endif
