@@ -90,8 +90,8 @@ DeviceConfigureDialog::DeviceConfigureDialog( const Medium &medium )
         m_transcodeWhenNecessary = new TQRadioButton( transcodeGroup );
         m_transcodeWhenNecessary->setText( i18n( "When necessary" ) );
         m_transcodeWhenNecessary->setChecked( !device->m_transcodeAlways );
-        connect( m_transcodeCheck, TQT_SIGNAL(toggled( bool )),
-                transcodeGroup, TQT_SLOT(setEnabled( bool )) );
+        connect( m_transcodeCheck, TQ_SIGNAL(toggled( bool )),
+                transcodeGroup, TQ_SLOT(setEnabled( bool )) );
         transcodeGroup->insert( m_transcodeAlways );
         transcodeGroup->insert( m_transcodeWhenNecessary );
         m_transcodeRemove = new TQCheckBox( transcodeGroup );
@@ -99,8 +99,8 @@ DeviceConfigureDialog::DeviceConfigureDialog( const Medium &medium )
         m_transcodeRemove->setChecked( device->m_transcodeRemove );
 
         const ScriptManager *sm = ScriptManager::instance();
-        m_transcodeCheck->setEnabled( sm->transcodeScriptRunning() != TQString::null );
-        transcodeGroup->setEnabled( sm->transcodeScriptRunning() != TQString::null && device->m_transcode );
+        m_transcodeCheck->setEnabled( !sm->transcodeScriptRunning().isEmpty() );
+        transcodeGroup->setEnabled( !sm->transcodeScriptRunning().isEmpty() && device->m_transcode );
         if( sm->transcodeScriptRunning().isNull() )
         {
             TQToolTip::add( m_transcodeCheck, i18n( "For this feature, a script of type \"Transcode\" has to be running" ) );
