@@ -39,11 +39,7 @@
 
 #ifndef ASSERT
 #if defined (DEBUG) || defined (_DEBUG)
-#if defined (_OSF1) && defined (_NATIVE_COMPILER)
-#	define ASSERT(x)	assert(((long)(x)) != 0L)
-#else
-#       define ASSERT(x)        assert(x)
-#endif
+# define ASSERT(x)  assert(x)
 #else
 #	define ASSERT(x)	/* x */
 #endif /* DEBUG */
@@ -68,14 +64,6 @@ extern "C" {
 #endif
 #endif
 
-#if defined (_OSF1) && defined (_NATIVE_COMPILER)
-#if defined __cplusplus
-#define __inline inline
-#else
-#define __inline static
-#endif /* __cplusplus */
-#endif
-
 #ifdef _HPUX 
 #if defined __cplusplus
 #define __inline inline
@@ -429,8 +417,6 @@ int safe_int_func_call(LONG32 f);
 
 #endif
 
-#elif defined ( __MWERKS__ )
-#define HX_SAFE_VOID2HANDLE(f)	(f)
 #elif defined ( _UNIX )
 #define HX_SAFE_VOID2HANDLE(f)	(f)
 #endif // end of#if defined(_WIN32) || defined(_WINDOWS)
