@@ -32,7 +32,7 @@ namespace Amarok { class Slider; }
 
 class EqualizerSetup : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
