@@ -31,7 +31,7 @@ HintLineEdit::init()
     reparent( m_vbox, 0, TQPoint(0,0), true );
     m_hint = new TQLabel( m_vbox );
     //m_hint->setBuddy( this );
-    m_hint->setFocusPolicy( TQ_NoFocus );
+    m_hint->setFocusPolicy( TQWidget::NoFocus );
     TQFont font;
     font.setPointSize( font.pointSize() - 2);
     m_hint->setFont( font );
