@@ -24,12 +24,12 @@
 #include <tqobject.h>
 
 class KDirOperator;
-class KPopupMenu;
+class TDEPopupMenu;
 
 class KBookmarkHandler : public TQObject, public KBookmarkOwner
 {
 public:
-    KBookmarkHandler( KDirOperator *parent, KPopupMenu* );
+    KBookmarkHandler( KDirOperator *parent, TDEPopupMenu* );
 
     /// KBookmarkOwner interface:
     virtual void openBookmarkURL( const TQString &url );
