@@ -143,15 +143,10 @@ UniversalAmarok::~UniversalAmarok()
 
 #include "universalamarok.moc"
 
-#if ! KDE_IS_VERSION(3,4,0)
-#define KDE_EXPORT __attribute__ ((visibility("default")))
-#endif
-
 // FIXME: is this referenced from anywhere ??!
-
 extern "C"
 {
-    KDE_EXPORT void* create_konqsidebar_universalamarok(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
+    TDE_EXPORT void* create_konqsidebar_universalamarok(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
     {
         TDEGlobal::locale()->insertCatalogue( "amarok" );
         return new UniversalAmarok(instance,par,widp,desktopname,name);
@@ -161,7 +156,7 @@ extern "C"
 // FIXME: Is this referenced from anywhere ??!
 extern "C"
 {
-    KDE_EXPORT bool add_konqsidebar_universalamarok(TQString* fn, TQString* param, TQMap<TQString,TQString> *map)
+    TDE_EXPORT bool add_konqsidebar_universalamarok(TQString* fn, TQString* param, TQMap<TQString,TQString> *map)
         {
         Q_UNUSED(param);
 
