@@ -69,10 +69,10 @@ AmarokHttp::get ( const TQString & path )
     m_error = TQHttp::NoError;
     m_state = TQHttp::Connecting;
     TDEIO::TransferJob *job = TDEIO::get(uri, true, false);
-    connect(job,  TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
-    connect(job,  TQT_SIGNAL(result(TDEIO::Job*)),
-            this, TQT_SLOT(slotResult(TDEIO::Job*)));
+    connect(job,  TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+    connect(job,  TQ_SIGNAL(result(TDEIO::Job*)),
+            this, TQ_SLOT(slotResult(TDEIO::Job*)));
 
     return 0;
 }
@@ -138,13 +138,13 @@ Controller::Controller()
 {
     TDEActionCollection* ac = Amarok::actionCollection();
     m_actionList.append( new TDEAction( i18n( "Ban" ), Amarok::icon( "remove" ),
-                         KKey( TQt::CTRL | TQt::Key_B ), this, TQT_SLOT( ban() ), ac, "ban" ) );
+                         KKey( TQt::CTRL | TQt::Key_B ), this, TQ_SLOT( ban() ), ac, "ban" ) );
 
     m_actionList.append( new TDEAction( i18n( "Love" ), Amarok::icon( "love" ),
-                         KKey( TQt::CTRL | TQt::Key_L ), this, TQT_SLOT( love() ), ac, "love" ) );
+                         KKey( TQt::CTRL | TQt::Key_L ), this, TQ_SLOT( love() ), ac, "love" ) );
 
     m_actionList.append( new TDEAction( i18n( "Skip" ), Amarok::icon( "next" ),
-                         KKey( TQt::CTRL | TQt::Key_K ), this, TQT_SLOT( skip() ), ac, "skip" ) );
+                         KKey( TQt::CTRL | TQt::Key_K ), this, TQ_SLOT( skip() ), ac, "skip" ) );
     setActionsEnabled( false );
 }
 
@@ -505,8 +505,8 @@ WebService::handshake( const TQString& username, const TQString& password )
         if (this->wasCanceled())
             return false;
     
-        connect( m_server, TQT_SIGNAL( readReady( KProcIO* ) ), this, TQT_SLOT( readProxy() ) );
-        connect( m_server, TQT_SIGNAL( processExited( TDEProcess* ) ), Controller::instance(), TQT_SLOT( playbackStopped() ) );
+        connect( m_server, TQ_SIGNAL( readReady( KProcIO* ) ), this, TQ_SLOT( readProxy() ) );
+        connect( m_server, TQ_SIGNAL( processExited( TDEProcess* ) ), Controller::instance(), TQ_SLOT( playbackStopped() ) );
     }
     else
         m_proxyUrl = m_streamUrl.toString();
@@ -565,7 +565,7 @@ void
 WebService::requestMetaData() //SLOT
 {
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( metaDataFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( metaDataFinished( int, bool ) ) );
 
     http->get( TQString( m_basePath + "/np.php?session=%1&debug=%2" )
                   .arg( m_session )
@@ -621,7 +621,7 @@ WebService::metaDataFinished( int /*id*/, bool error ) //SLOT
     }
 
     TDEIO::Job* job = TDEIO::storedGet( u, true, false );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( fetchImageFinished( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( fetchImageFinished( TDEIO::Job* ) ) );
 }
 
 
@@ -652,7 +652,7 @@ WebService::enableScrobbling( bool enabled ) //SLOT
         debug() << "Disabling Scrobbling!" << endl;
 
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( enableScrobblingFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( enableScrobblingFinished( int, bool ) ) );
 
     http->get( TQString( m_basePath + "/control.php?session=%1&command=%2&debug=%3" )
                   .arg( m_session )
@@ -676,7 +676,7 @@ void
 WebService::love() //SLOT
 {
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( loveFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( loveFinished( int, bool ) ) );
 
     http->get( TQString( m_basePath + "/control.php?session=%1&command=love&debug=%2" )
                   .arg( m_session )
@@ -689,7 +689,7 @@ void
 WebService::skip() //SLOT
 {
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( skipFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( skipFinished( int, bool ) ) );
 
     http->get( TQString( m_basePath + "/control.php?session=%1&command=skip&debug=%2" )
                   .arg( m_session )
@@ -702,7 +702,7 @@ void
 WebService::ban() //SLOT
 {
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( int, bool ) ), this, TQT_SLOT( banFinished( int, bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( int, bool ) ), this, TQ_SLOT( banFinished( int, bool ) ) );
 
     http->get( TQString( m_basePath + "/control.php?session=%1&command=ban&debug=%2" )
                   .arg( m_session )
@@ -760,7 +760,7 @@ WebService::friends( TQString username )
         username = m_username;
 
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( bool ) ), this, TQT_SLOT( friendsFinished( bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( bool ) ), this, TQ_SLOT( friendsFinished( bool ) ) );
 
     http->get( TQString( "/1.0/user/%1/friends.xml" )
                   .arg( TQString( TQUrl( username ).encodedPathAndQuery() ) ) );
@@ -802,7 +802,7 @@ WebService::neighbours( TQString username )
         username = m_username;
 
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( bool ) ), this, TQT_SLOT( neighboursFinished( bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( bool ) ), this, TQ_SLOT( neighboursFinished( bool ) ) );
 
     http->get( TQString( "/1.0/user/%1/neighbours.xml" )
                   .arg( TQString( TQUrl( username ).encodedPathAndQuery() ) ) );
@@ -844,7 +844,7 @@ WebService::userTags( TQString username )
         username = m_username;
 
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( bool ) ), this, TQT_SLOT( userTagsFinished( bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( bool ) ), this, TQ_SLOT( userTagsFinished( bool ) ) );
 
     http->get( TQString( "/1.0/user/%1/tags.xml?debug=%2" )
                   .arg( TQString( TQUrl( username ).encodedPathAndQuery() ) ) );
@@ -886,7 +886,7 @@ WebService::recentTracks( TQString username )
         username = m_username;
 
     AmarokHttp *http = new AmarokHttp( m_baseHost, 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( bool ) ), this, TQT_SLOT( recentTracksFinished( bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( bool ) ), this, TQ_SLOT( recentTracksFinished( bool ) ) );
 
     http->get( TQString( "/1.0/user/%1/recenttracks.xml" )
                   .arg( TQString( TQUrl( username ).encodedPathAndQuery() ) ) );
@@ -948,9 +948,9 @@ WebService::recommend( int type, TQString username, TQString artist, TQString to
     }
 
     TQHttp *http = new TQHttp( "wsdev.audioscrobbler.com", 80, this );
-    connect( http, TQT_SIGNAL( requestFinished( bool ) ), this, TQT_SLOT( recommendFinished( bool ) ) );
+    connect( http, TQ_SIGNAL( requestFinished( bool ) ), this, TQ_SLOT( recommendFinished( bool ) ) );
 
-    uint currentTime = TQDateTime::currentDateTime( Qt::UTC ).toTime_t();
+    uint currentTime = TQDateTime::currentDateTime( TQt::UTC ).toTime_t();
     TQString challenge = TQString::number( currentTime );
 
     TQCString md5pass = KMD5( KMD5( m_password.utf8() ).hexDigest() + currentTime ).hexDigest();
@@ -1096,10 +1096,10 @@ void Bundle::detach() {
 LoginDialog::LoginDialog( TQWidget *parent )
     : KDialogBase( parent, "LastfmLogin", true, TQString(), Ok|Cancel)
 {
-    makeGridMainWidget( 1, Qt::Horizontal );
+    makeGridMainWidget( 1, TQt::Horizontal );
     new TQLabel( i18n( "To use last.fm with Amarok, you need a last.fm profile." ), mainWidget() );
 
-    makeGridMainWidget( 2, Qt::Horizontal );
+    makeGridMainWidget( 2, TQt::Horizontal );
     TQLabel *nameLabel = new TQLabel( i18n("&Username:"), mainWidget() );
     m_userLineEdit = new KLineEdit( mainWidget() );
     nameLabel->setBuddy( m_userLineEdit );
