@@ -170,7 +170,7 @@ Loader::Loader( TQStringList args )
 
     args.prepend( "amarokapp" );
 
-    m_proc = new TQProcess( args, TQT_TQOBJECT(this) );
+    m_proc = new TQProcess( args, this );
     m_proc->setCommunication( TQProcess::Stdout );
 
     std::cout << "Amarok: [Loader] Starting amarokapp..\n";
