@@ -35,7 +35,7 @@ This class encapsulates the downloading of an album once all required informatio
 */
 class MagnatuneAlbumDownloader: public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     MagnatuneAlbumDownloader();
