@@ -50,7 +50,7 @@ Implemented as a singleton
 */
 class MagnatuneBrowser : public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
