@@ -27,7 +27,7 @@ namespace Daap {
 */
 class ContentFetcher : public TQHttp
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
