@@ -54,7 +54,7 @@ MediumPluginManagerDialog::MediumPluginManagerDialog()
     vbox->setSpacing( KDialog::spacingHint() );
     vbox->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
 
-    m_location = new TQGroupBox( 1, Qt::Vertical, i18n( "Devices" ), vbox );
+    m_location = new TQGroupBox( 1, TQt::Vertical, i18n( "Devices" ), vbox );
     m_location->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Preferred ) );
     m_devicesBox = new TQVBox( m_location );
     m_devicesBox->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
@@ -64,11 +64,11 @@ MediumPluginManagerDialog::MediumPluginManagerDialog()
     TQHBox *hbox = new TQHBox( vbox );
     KPushButton *detectDevices = new KPushButton( i18n( "Autodetect Devices" ), hbox);
     detectDevices->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ) );
-    connect( detectDevices, TQT_SIGNAL( clicked() ), m_manager, TQT_SLOT( redetectDevices() ) );
+    connect( detectDevices, TQ_SIGNAL( clicked() ), m_manager, TQ_SLOT( redetectDevices() ) );
 
     KPushButton *addButton = new KPushButton( i18n( "Add Device..." ), hbox );
     addButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ) );
-    connect( addButton, TQT_SIGNAL( clicked() ), m_manager, TQT_SLOT( newDevice() ) );
+    connect( addButton, TQ_SIGNAL( clicked() ), m_manager, TQ_SLOT( newDevice() ) );
 }
 
 MediumPluginManagerDialog::~MediumPluginManagerDialog()
@@ -88,7 +88,7 @@ MediumPluginManager::MediumPluginManager( TQWidget *widget, const bool nographic
 {
     detectDevices( false, nographics );
 
-    connect( this, TQT_SIGNAL( selectedPlugin( const Medium*, const TQString ) ), MediaBrowser::instance(), TQT_SLOT( pluginSelected( const Medium*, const TQString ) ) );
+    connect( this, TQ_SIGNAL( selectedPlugin( const Medium*, const TQString ) ), MediaBrowser::instance(), TQ_SLOT( pluginSelected( const Medium*, const TQString ) ) );
 }
 
 MediumPluginManager::~MediumPluginManager()
@@ -154,7 +154,7 @@ MediumPluginManager::detectDevices( const bool redetect, const bool nographics )
 
         MediaDeviceConfig *dev = new MediaDeviceConfig( *it, this, nographics, m_widget );
         m_deviceList.append( dev );
-        connect( dev, TQT_SIGNAL(deleteMedium(Medium *)), TQT_SLOT(deleteMedium(Medium *)) );
+        connect( dev, TQ_SIGNAL(deleteMedium(Medium *)), TQ_SLOT(deleteMedium(Medium *)) );
 
         foundNew = true;
     }
@@ -168,11 +168,8 @@ MediumPluginManager::redetectDevices()
     if( !detectDevices( true ) )
     {
         Amarok::StatusBar::instance()->longMessageThreadSafe( i18n("No new media devices were found. If you feel this is an\n"
-                                                                   "error, ensure that the DBUS and HAL daemons are running\n"
-                                                                   "and KDE was built with support for them. You can test this\n"
-                                                                   "by running\n"
-                                                                   "     \"dcop kded mediamanager fullList\"\n"
-                                                                   "in a Konsole window.") );
+                                                                   "error, ensure that the DBUS and either TDEHW or HAL daemon are running\n"
+                                                                   "and TDE was built with support for them.") );
     }
     else
         slotChanged();
@@ -291,7 +288,7 @@ ManualDeviceAdder::ManualDeviceAdder( MediumPluginManager* mpm )
     m_mdaMountPoint->setHint( i18n( "Example: /mnt/ipod" ) );
     TQToolTip::add( m_mdaMountPoint, i18n( "Enter the device's mount point.  Some devices (such as iRiver iFP devices) may not have a mount point and this can be ignored.  All other devices (iPods, UMS/VFAT devices) should enter the mount point here." ) );
 
-    connect( m_mdaCombo, TQT_SIGNAL( activated(const TQString&) ), this, TQT_SLOT( comboChanged(const TQString&) ) );
+    connect( m_mdaCombo, TQ_SIGNAL( activated(const TQString&) ), this, TQ_SLOT( comboChanged(const TQString&) ) );
 }
 
 ManualDeviceAdder::~ManualDeviceAdder()
@@ -436,16 +433,16 @@ MediaDeviceConfig::MediaDeviceConfig( Medium *medium, MediumPluginManager *mgr,
     }
 
     m_configButton = new KPushButton( SmallIconSet( Amarok::icon( "configure" ) ), TQString(), this );
-    connect( m_configButton, TQT_SIGNAL(clicked()), TQT_SLOT(configureDevice()) );
+    connect( m_configButton, TQ_SIGNAL(clicked()), TQ_SLOT(configureDevice()) );
     m_configButton->setEnabled( !m_new && m_pluginCombo->currentText() != i18n( "Do not handle" ) );
     TQToolTip::add( m_configButton, i18n( "Configure device settings" ) );
 
     m_removeButton = new KPushButton( i18n( "Remove" ), this );
-    connect( m_removeButton, TQT_SIGNAL(clicked()), TQT_SLOT(deleteDevice()) );
+    connect( m_removeButton, TQ_SIGNAL(clicked()), TQ_SLOT(deleteDevice()) );
     TQToolTip::add( m_removeButton, i18n( "Remove entries corresponding to this device from configuration file" ) );
 
-    connect( m_pluginCombo, TQT_SIGNAL(activated(const TQString&)), m_manager, TQT_SLOT(slotChanged()) );
-    connect( this, TQT_SIGNAL(changed()), m_manager, TQT_SLOT(slotChanged()) );
+    connect( m_pluginCombo, TQ_SIGNAL(activated(const TQString&)), m_manager, TQ_SLOT(slotChanged()) );
+    connect( this, TQ_SIGNAL(changed()), m_manager, TQ_SLOT(slotChanged()) );
 
     if( !nographics )
         show();
