@@ -59,7 +59,7 @@ class DropProxyTarget
 */
 class MultiTabBar: public TQWidget
 {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         enum MultiTabBarMode{Horizontal, Vertical};
@@ -173,7 +173,7 @@ class MultiTabBar: public TQWidget
 */
 class MultiTabBarButton: public TQPushButton
 {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         MultiTabBarButton( const TQPixmap& pic, const TQString&, TQPopupMenu *popup,
@@ -250,7 +250,7 @@ class MultiTabBarButton: public TQPushButton
 */
 class MultiTabBarTab: public MultiTabBarButton
 {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         MultiTabBarTab( const TQPixmap& pic, const TQString&, int id, TQWidget *parent,
