@@ -119,7 +119,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
     //another quit shortcut because the other window has all the accels
     TQAccel *accel = new TQAccel( this );
     accel->insertItem( CTRL + Key_Q );
-    connect( accel, TQT_SIGNAL( activated( int ) ), kapp, TQT_SLOT( quit() ) );
+    connect( accel, TQ_SIGNAL( activated( int ) ), kapp, TQ_SLOT( quit() ) );
 
     TQFont font;
     font.setBold( true );
@@ -142,7 +142,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
         KPushButton *switchView = new KPushButton( KGuiItem( "", "mini_dock" ), m_pFrameButtons );
         switchView->setSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ); // too big!
         switchView->setFocusPolicy( TQWidget::NoFocus );
-        connect( switchView, TQT_SIGNAL( clicked() ), TQT_SLOT( toggleView() ) );
+        connect( switchView, TQ_SIGNAL( clicked() ), TQ_SLOT( toggleView() ) );
 
 
         m_pButtonPlay->setToggleButton( true );
@@ -150,9 +150,9 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
     } //</NavButtons>
 
     { //<Sliders>
-        m_pSlider    = new Amarok::PrettySlider( Qt::Horizontal,
+        m_pSlider    = new Amarok::PrettySlider( TQt::Horizontal,
                                                  Amarok::PrettySlider::Pretty, this );
-        m_pVolSlider = new Amarok::PrettySlider( Qt::Vertical,
+        m_pVolSlider = new Amarok::PrettySlider( TQt::Vertical,
                                                  Amarok::PrettySlider::Pretty, this,
                                                  Amarok::VOLUME_MAX );
 
@@ -161,10 +161,10 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
         m_pVolSlider->setValue( AmarokConfig::masterVolume() );
 
         EngineController* const ec = EngineController::instance();
-        connect( m_pSlider, TQT_SIGNAL(sliderReleased( int )), ec, TQT_SLOT(seek( int )) );
-        connect( m_pSlider, TQT_SIGNAL(valueChanged( int )), TQT_SLOT(timeDisplay( int )) );
-        connect( m_pVolSlider, TQT_SIGNAL(sliderMoved( int )), ec, TQT_SLOT(setVolume( int )) );
-        connect( m_pVolSlider, TQT_SIGNAL(sliderReleased( int )), ec, TQT_SLOT(setVolume( int )) );
+        connect( m_pSlider, TQ_SIGNAL(sliderReleased( int )), ec, TQ_SLOT(seek( int )) );
+        connect( m_pSlider, TQ_SIGNAL(valueChanged( int )), TQ_SLOT(timeDisplay( int )) );
+        connect( m_pVolSlider, TQ_SIGNAL(sliderMoved( int )), ec, TQ_SLOT(setVolume( int )) );
+        connect( m_pVolSlider, TQ_SIGNAL(sliderReleased( int )), ec, TQ_SLOT(setVolume( int )) );
     } //<Sliders>
 
     { //<Scroller>
@@ -186,11 +186,11 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
     } //<TimeLabel>
 
 
-    m_pButtonEq = new IconButton( TQT_TQWIDGET(this), "eq", TQT_TQOBJECT(this), TQT_SLOT(slotShowEqualizer( bool )) );
+    m_pButtonEq = new IconButton( this, "eq", this, TQ_SLOT(slotShowEqualizer( bool )) );
     m_pButtonEq->setGeometry( 34,85, 28,13 );
     //TODO set isOn()
 
-    m_pPlaylistButton = new IconButton( this, "pl", TQT_SIGNAL(playlistToggled( bool )) );
+    m_pPlaylistButton = new IconButton( this, "pl", TQ_SIGNAL(playlistToggled( bool )) );
     m_pPlaylistButton->setGeometry( 5,85, 28,13 );
     m_pPlaylistButton->setOn( parent->isShown() || enablePlaylist );
 
@@ -219,7 +219,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
     //KWin::setType( winId(), NET::Override );
     //KWin::setOnAllDesktops( winId(), true );
 
-    connect( m_pAnimTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( drawScroll() ) );
+    connect( m_pAnimTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( drawScroll() ) );
 
     TrackToolTip::instance()->addToWidget( m_pScrollFrame );
 }
@@ -557,7 +557,7 @@ bool PlayerWidget::event( TQEvent *e )
         return true;
 
     case 6/*TQEvent::KeyPress*/:
-        if (TQT_TQKEYEVENT(e)->key() == TQt::Key_D/* && (m_pAnalyzer->inherits("TQGLWidget")*/)
+        if (static_cast<TQKeyEvent*>(e)->key() == TQt::Key_D/* && (m_pAnalyzer->inherits("TQGLWidget")*/)
         {
             if( m_pAnalyzer->parent() )
             {
@@ -703,7 +703,7 @@ PlayerWidget::eventFilter( TQObject *o, TQEvent *e )
     {
     case TQEvent::Close:
 
-        TQT_TQCLOSEEVENT(e)->accept(); //close the window!
+        static_cast<TQCloseEvent*>(e)->accept(); //close the window!
         return true; //don't let PlaylistWindow have the event - see PlaylistWindow::closeEvent()
 
     case TQEvent::Hide:
@@ -770,7 +770,7 @@ void PlayerWidget::contextMenuEvent( TQMouseEvent *e )
 
 void PlayerWidget::mousePressEvent( TQMouseEvent *e )
 {
-    if ( e->button() == Qt::RightButton )
+    if ( e->button() == TQt::RightButton )
     {
         //Amarok::Menu::instance()->exec( e->globalPos() );
     }
@@ -796,7 +796,7 @@ void PlayerWidget::mousePressEvent( TQMouseEvent *e )
 
 void PlayerWidget::mouseMoveEvent( TQMouseEvent *e )
 {
-    if( e->state() & Qt::LeftButton )
+    if( e->state() & TQt::LeftButton )
     {
         const int distance = (e->pos() - m_startDragPos).manhattanLength();
 
@@ -838,7 +838,7 @@ void PlayerWidget::slotShowEqualizer( bool show ) //SLOT
             KMessageBox::sorry( 0, i18n( "Equalizer is not available with this engine." ) );
 
         else
-            TQTimer::singleShot( 0, kapp, TQT_SLOT( slotConfigEqualizer() ) );
+            TQTimer::singleShot( 0, kapp, TQ_SLOT( slotConfigEqualizer() ) );
     }
 }
 
@@ -899,8 +899,8 @@ NavButton::NavButton( TQWidget *parent, const TQString &icon, TDEAction *action
     setFocusPolicy( TQWidget::NoFocus );
     setEnabled( action->isEnabled() );
 
-    connect( action, TQT_SIGNAL( enabled( bool ) ),   TQT_SLOT( setEnabled( bool ) ) );
-    connect( this,   TQT_SIGNAL( clicked() ), action, TQT_SLOT( activate() ) );
+    connect( action, TQ_SIGNAL( enabled( bool ) ),   TQ_SLOT( setEnabled( bool ) ) );
+    connect( this,   TQ_SIGNAL( clicked() ), action, TQ_SLOT( activate() ) );
     startTimer( GLOW_INTERVAL );
 }
 
@@ -940,7 +940,7 @@ IconButton::IconButton( TQWidget *parent, const TQString &icon, const char *sign
     , m_up(   getPNG( icon + "_active2" ) ) //TODO rename files better (like the right way round for one!)
     , m_down( getPNG( icon + "_inactive2" ) )
 {
-    connect( this, TQT_SIGNAL(toggled( bool )), parent, signal );
+    connect( this, TQ_SIGNAL(toggled( bool )), parent, signal );
 
     setToggleButton( true );
     setFocusPolicy( TQWidget::NoFocus ); //we have no way to show focus on these widgets currently
@@ -951,7 +951,7 @@ IconButton::IconButton( TQWidget *parent, const TQString &icon, TQObject* receiv
     , m_up(   getPNG( icon + "_active2" ) ) //TODO rename files better (like the right way round for one!)
     , m_down( getPNG( icon + "_inactive2" ) )
 {
-    connect( this, TQT_SIGNAL(toggled( bool )), receiver, slot );
+    connect( this, TQ_SIGNAL(toggled( bool )), receiver, slot );
 
     setToggleButton( true );
     setFocusPolicy( TQWidget::NoFocus ); //we have no way to show focus on these widgets currently
