@@ -123,38 +123,38 @@ PlaylistWindow::PlaylistWindow()
 
     new K3bExporter();
 
-    KStdAction::configureToolbars( TQT_TQOBJECT(kapp), TQT_SLOT( slotConfigToolBars() ), ac );
-    KStdAction::keyBindings( TQT_TQOBJECT(kapp), TQT_SLOT( slotConfigShortcuts() ), ac );
-    KStdAction::keyBindings( TQT_TQOBJECT(kapp), TQT_SLOT( slotConfigGlobalShortcuts() ), ac, "options_configure_globals" );
-    KStdAction::preferences( TQT_TQOBJECT(kapp), TQT_SLOT( slotConfigAmarok() ), ac );
+    KStdAction::configureToolbars( kapp, TQ_SLOT( slotConfigToolBars() ), ac );
+    KStdAction::keyBindings( kapp, TQ_SLOT( slotConfigShortcuts() ), ac );
+    KStdAction::keyBindings( kapp, TQ_SLOT( slotConfigGlobalShortcuts() ), ac, "options_configure_globals" );
+    KStdAction::preferences( kapp, TQ_SLOT( slotConfigAmarok() ), ac );
     ac->action("options_configure_globals")->setIcon( Amarok::icon( "configure" ) );
     ac->action(KStdAction::name(KStdAction::KeyBindings))->setIcon( Amarok::icon( "configure" ) );
     ac->action(KStdAction::name(KStdAction::ConfigureToolbars))->setIcon( Amarok::icon( "configure" ) );
     ac->action(KStdAction::name(KStdAction::Preferences))->setIcon( Amarok::icon( "configure" ) );
 
-    KStdAction::quit( TQT_TQOBJECT(kapp), TQT_SLOT( quit() ), ac );
-    KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT(slotAddLocation()), ac, "playlist_add" )->setText( i18n("&Add Media...") );
+    KStdAction::quit( kapp, TQ_SLOT( quit() ), ac );
+    KStdAction::open( this, TQ_SLOT(slotAddLocation()), ac, "playlist_add" )->setText( i18n("&Add Media...") );
     ac->action( "playlist_add" )->setIcon( Amarok::icon( "files" ) );
-    KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT(slotAddStream()), ac, "stream_add" )->setText( i18n("&Add Stream...") );
+    KStdAction::open( this, TQ_SLOT(slotAddStream()), ac, "stream_add" )->setText( i18n("&Add Stream...") );
     ac->action( "stream_add" )->setIcon( Amarok::icon( "files" ) );
-    KStdAction::save( TQT_TQOBJECT(this), TQT_SLOT(savePlaylist()), ac, "playlist_save" )->setText( i18n("&Save Playlist As...") );
+    KStdAction::save( this, TQ_SLOT(savePlaylist()), ac, "playlist_save" )->setText( i18n("&Save Playlist As...") );
     ac->action( "playlist_save" )->setIcon( Amarok::icon( "save" ) );
 #ifndef TQ_WS_MAC
-    KStdAction::showMenubar( TQT_TQOBJECT(this), TQT_SLOT(slotToggleMenu()), ac );
+    KStdAction::showMenubar( this, TQ_SLOT(slotToggleMenu()), ac );
 #endif
 
     //FIXME: after string freeze rename to "Burn Current Playlist"?
-    new TDEAction( i18n("Burn to CD"), Amarok::icon( "burn" ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotBurnPlaylist()), ac, "playlist_burn" );
+    new TDEAction( i18n("Burn to CD"), Amarok::icon( "burn" ), 0, this, TQ_SLOT(slotBurnPlaylist()), ac, "playlist_burn" );
     actionCollection()->action("playlist_burn")->setEnabled( K3bExporter::isAvailable() );
-    new TDEAction( i18n("Play Media..."), Amarok::icon( "files" ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlayMedia()), ac, "playlist_playmedia" );
-    new TDEAction( i18n("Play Audio CD"), Amarok::icon( "album" ), 0, TQT_TQOBJECT(this), TQT_SLOT(playAudioCD()), ac, "play_audiocd" );
-    TDEAction *playPause = new TDEAction( i18n( "&Play/Pause" ), Amarok::icon( "play" ), Key_Space, ec, TQT_SLOT( playPause() ), ac, "play_pause" );
-    new TDEAction( i18n("Script Manager"), Amarok::icon( "scripts" ), 0, TQT_TQOBJECT(this), TQT_SLOT(showScriptSelector()), ac, "script_manager" );
-    new TDEAction( i18n("Queue Manager"), Amarok::icon( "queue" ), 0, TQT_TQOBJECT(this), TQT_SLOT(showQueueManager()), ac, "queue_manager" );
-    TDEAction *seekForward = new TDEAction( i18n( "&Seek Forward" ), Amarok::icon( "fastforward" ), Key_Right, ec, TQT_SLOT( seekForward() ), ac, "seek_forward" );
-    TDEAction *seekBackward = new TDEAction( i18n( "&Seek Backward" ), Amarok::icon( "rewind" ), Key_Left, ec, TQT_SLOT( seekBackward() ), ac, "seek_backward" );
-    new TDEAction( i18n("Statistics"), Amarok::icon( "info" ), 0, TQT_TQOBJECT(this), TQT_SLOT(showStatistics()), ac, "statistics" );
-    new TDEAction( i18n("Update Collection"), Amarok::icon( "refresh" ), 0, CollectionDB::instance(), TQT_SLOT( scanModifiedDirs() ), actionCollection(), "update_collection" );
+    new TDEAction( i18n("Play Media..."), Amarok::icon( "files" ), 0, this, TQ_SLOT(slotPlayMedia()), ac, "playlist_playmedia" );
+    new TDEAction( i18n("Play Audio CD"), Amarok::icon( "album" ), 0, this, TQ_SLOT(playAudioCD()), ac, "play_audiocd" );
+    TDEAction *playPause = new TDEAction( i18n( "&Play/Pause" ), Amarok::icon( "play" ), Key_Space, ec, TQ_SLOT( playPause() ), ac, "play_pause" );
+    new TDEAction( i18n("Script Manager"), Amarok::icon( "scripts" ), 0, this, TQ_SLOT(showScriptSelector()), ac, "script_manager" );
+    new TDEAction( i18n("Queue Manager"), Amarok::icon( "queue" ), 0, this, TQ_SLOT(showQueueManager()), ac, "queue_manager" );
+    TDEAction *seekForward = new TDEAction( i18n( "&Seek Forward" ), Amarok::icon( "fastforward" ), Key_Right, ec, TQ_SLOT( seekForward() ), ac, "seek_forward" );
+    TDEAction *seekBackward = new TDEAction( i18n( "&Seek Backward" ), Amarok::icon( "rewind" ), Key_Left, ec, TQ_SLOT( seekBackward() ), ac, "seek_backward" );
+    new TDEAction( i18n("Statistics"), Amarok::icon( "info" ), 0, this, TQ_SLOT(showStatistics()), ac, "statistics" );
+    new TDEAction( i18n("Update Collection"), Amarok::icon( "refresh" ), 0, CollectionDB::instance(), TQ_SLOT( scanModifiedDirs() ), actionCollection(), "update_collection" );
 
     m_lastfmTags << "Alternative" << "Ambient" << "Chill Out" << "Classical" << "Dance"
                  << "Electronica" << "Favorites" << "Heavy Metal" << "Hip Hop" << "Indie Rock"
@@ -164,39 +164,39 @@ PlaylistWindow::PlaylistWindow()
     TDEPopupMenu* playTagRadioMenu = new TDEPopupMenu( this );
     int id = 0;
     foreach( m_lastfmTags ) {
-        playTagRadioMenu->insertItem( *it, this, TQT_SLOT( playLastfmGlobaltag( int ) ), 0, id );
+        playTagRadioMenu->insertItem( *it, this, TQ_SLOT( playLastfmGlobaltag( int ) ), 0, id );
         ++id;
     }
 
     TDEPopupMenu* addTagRadioMenu = new TDEPopupMenu( this );
     id = 0;
     foreach( m_lastfmTags ) {
-        addTagRadioMenu->insertItem( *it, this, TQT_SLOT( addLastfmGlobaltag( int ) ), 0, id );
+        addTagRadioMenu->insertItem( *it, this, TQ_SLOT( addLastfmGlobaltag( int ) ), 0, id );
         ++id;
     }
 
     TDEActionMenu* playLastfm = new TDEActionMenu( i18n( "Play las&t.fm Stream" ), Amarok::icon( "audioscrobbler" ), ac, "lastfm_play" );
     TQPopupMenu* playLastfmMenu = playLastfm->popupMenu();
-    playLastfmMenu->insertItem( i18n( "Personal Radio" ), this, TQT_SLOT( playLastfmPersonal() ) );
-    playLastfmMenu->insertItem( i18n( "Neighbor Radio" ), this, TQT_SLOT( playLastfmNeighbor() ) );
-    playLastfmMenu->insertItem( i18n( "Custom Station" ), this, TQT_SLOT( playLastfmCustom() ) );
+    playLastfmMenu->insertItem( i18n( "Personal Radio" ), this, TQ_SLOT( playLastfmPersonal() ) );
+    playLastfmMenu->insertItem( i18n( "Neighbor Radio" ), this, TQ_SLOT( playLastfmNeighbor() ) );
+    playLastfmMenu->insertItem( i18n( "Custom Station" ), this, TQ_SLOT( playLastfmCustom() ) );
     playLastfmMenu->insertItem( i18n( "Global Tag Radio" ), playTagRadioMenu );
 
     TDEActionMenu* addLastfm = new TDEActionMenu( i18n( "Add las&t.fm Stream" ), Amarok::icon( "audioscrobbler" ), ac, "lastfm_add" );
     TQPopupMenu* addLastfmMenu = addLastfm->popupMenu();
-    addLastfmMenu->insertItem( i18n( "Personal Radio" ), this, TQT_SLOT( addLastfmPersonal() ) );
-    addLastfmMenu->insertItem( i18n( "Neighbor Radio" ), this, TQT_SLOT( addLastfmNeighbor() ) );
-    addLastfmMenu->insertItem( i18n( "Custom Station" ), this, TQT_SLOT( addLastfmCustom() ) );
+    addLastfmMenu->insertItem( i18n( "Personal Radio" ), this, TQ_SLOT( addLastfmPersonal() ) );
+    addLastfmMenu->insertItem( i18n( "Neighbor Radio" ), this, TQ_SLOT( addLastfmNeighbor() ) );
+    addLastfmMenu->insertItem( i18n( "Custom Station" ), this, TQ_SLOT( addLastfmCustom() ) );
     addLastfmMenu->insertItem( i18n( "Global Tag Radio" ), addTagRadioMenu );
 
     ac->action( "options_configure_globals" )->setText( i18n( "Configure &Global Shortcuts..." ) );
 
-    new TDEAction( i18n( "Previous Track" ), Amarok::icon( "back" ), 0, ec, TQT_SLOT( previous() ), ac, "prev" );
-    new TDEAction( i18n( "Play" ), Amarok::icon( "play" ), 0, ec, TQT_SLOT( play() ), ac, "play" );
-    new TDEAction( i18n( "Pause" ), Amarok::icon( "pause" ), 0, ec, TQT_SLOT( pause() ), ac, "pause" );
-    new TDEAction( i18n( "Next Track" ), Amarok::icon( "next" ), 0, ec, TQT_SLOT( next() ), ac, "next" );
+    new TDEAction( i18n( "Previous Track" ), Amarok::icon( "back" ), 0, ec, TQ_SLOT( previous() ), ac, "prev" );
+    new TDEAction( i18n( "Play" ), Amarok::icon( "play" ), 0, ec, TQ_SLOT( play() ), ac, "play" );
+    new TDEAction( i18n( "Pause" ), Amarok::icon( "pause" ), 0, ec, TQ_SLOT( pause() ), ac, "pause" );
+    new TDEAction( i18n( "Next Track" ), Amarok::icon( "next" ), 0, ec, TQ_SLOT( next() ), ac, "next" );
 
-    TDEAction *toggleFocus = new TDEAction( i18n( "Toggle Focus" ), "reload", CTRL+Key_Tab, TQT_TQOBJECT(this), TQT_SLOT( slotToggleFocus() ), ac, "toggle_focus" );
+    TDEAction *toggleFocus = new TDEAction( i18n( "Toggle Focus" ), "reload", CTRL+Key_Tab, this, TQ_SLOT( slotToggleFocus() ), ac, "toggle_focus" );
 
 
     { // TDEAction idiocy -- shortcuts don't work until they've been plugged into a menu
@@ -287,10 +287,10 @@ void PlaylistWindow::init()
         m_lineEdit->setFrame( TQFrame::Sunken );
         m_lineEdit->installEventFilter( this ); //we intercept keyEvents
 
-        connect( button, TQT_SIGNAL(clicked()), m_lineEdit, TQT_SLOT(clear()) );
-        connect( m_lineEdit, TQT_SIGNAL(textChanged( const TQString& )),
-                playlist, TQT_SLOT(setFilterSlot( const TQString& )) );
-        connect( filterButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotEditFilter() ) );
+        connect( button, TQ_SIGNAL(clicked()), m_lineEdit, TQ_SLOT(clear()) );
+        connect( m_lineEdit, TQ_SIGNAL(textChanged( const TQString& )),
+                playlist, TQ_SLOT(setFilterSlot( const TQString& )) );
+        connect( filterButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotEditFilter() ) );
 
         TQToolTip::add( button, i18n( "Clear search field" ) );
         TQString filtertip = i18n( "Enter space-separated terms to search in the playlist.\n\n"
@@ -310,7 +310,7 @@ void PlaylistWindow::init()
     TQWidget *statusbar = new Amarok::StatusBar( this );
 
     TDEAction* repeatAction = Amarok::actionCollection()->action( "repeat" );
-    connect( repeatAction, TQT_SIGNAL( activated( int ) ), playlist, TQT_SLOT( slotRepeatTrackToggled( int ) ) );
+    connect( repeatAction, TQ_SIGNAL( activated( int ) ), playlist, TQ_SLOT( slotRepeatTrackToggled( int ) ) );
 
     m_menubar = new KMenuBar( this );
 #ifndef TQ_WS_MAC
@@ -330,7 +330,7 @@ void PlaylistWindow::init()
     actionsMenu->insertSeparator();
     actionCollection()->action(KStdAction::name(KStdAction::Quit))->plug( actionsMenu );
 
-    connect( actionsMenu, TQT_SIGNAL( aboutToShow() ), TQT_SLOT( actionsMenuAboutToShow() ) );
+    connect( actionsMenu, TQ_SIGNAL( aboutToShow() ), TQ_SLOT( actionsMenuAboutToShow() ) );
     //END Actions menu
 
     //BEGIN Playlist menu
@@ -368,7 +368,7 @@ void PlaylistWindow::init()
     m_toolsMenu->insertItem( SmallIconSet( Amarok::icon( "covermanager" ) ), i18n("&Cover Manager"), Amarok::Menu::ID_SHOW_COVER_MANAGER );
     actionCollection()->action("queue_manager")->plug( m_toolsMenu );
     m_toolsMenu->insertItem( SmallIconSet( Amarok::icon( "visualizations" ) ), i18n("&Visualizations"), Amarok::Menu::ID_SHOW_VIS_SELECTOR );
-    m_toolsMenu->insertItem( SmallIconSet( Amarok::icon( "equalizer") ), i18n("&Equalizer"), TQT_TQOBJECT(kapp), TQT_SLOT( slotConfigEqualizer() ), 0, Amarok::Menu::ID_CONFIGURE_EQUALIZER );
+    m_toolsMenu->insertItem( SmallIconSet( Amarok::icon( "equalizer") ), i18n("&Equalizer"), kapp, TQ_SLOT( slotConfigEqualizer() ), 0, Amarok::Menu::ID_CONFIGURE_EQUALIZER );
     actionCollection()->action("script_manager")->plug( m_toolsMenu );
     actionCollection()->action("statistics")->plug( m_toolsMenu );
     m_toolsMenu->insertSeparator();
@@ -381,8 +381,8 @@ void PlaylistWindow::init()
     m_toolsMenu->setItemEnabled( Amarok::Menu::ID_SHOW_VIS_SELECTOR, false );
     #endif
 
-    connect( m_toolsMenu, TQT_SIGNAL( aboutToShow() ), TQT_SLOT( toolsMenuAboutToShow() ) );
-    connect( m_toolsMenu, TQT_SIGNAL( activated(int) ), TQT_SLOT( slotMenuActivated(int) ) );
+    connect( m_toolsMenu, TQ_SIGNAL( aboutToShow() ), TQ_SLOT( toolsMenuAboutToShow() ) );
+    connect( m_toolsMenu, TQ_SIGNAL( activated(int) ), TQ_SLOT( slotMenuActivated(int) ) );
     //END Tools menu
 
     //BEGIN Settings menu
@@ -405,7 +405,7 @@ void PlaylistWindow::init()
     actionCollection()->action(KStdAction::name(KStdAction::ConfigureToolbars))->plug( m_settingsMenu );
     actionCollection()->action(KStdAction::name(KStdAction::Preferences))->plug( m_settingsMenu );
 
-    connect( m_settingsMenu, TQT_SIGNAL( activated(int) ), TQT_SLOT( slotMenuActivated(int) ) );
+    connect( m_settingsMenu, TQ_SIGNAL( activated(int) ), TQ_SLOT( slotMenuActivated(int) ) );
     //END Settings menu
 
     m_menubar->insertItem( i18n( "&File" ), actionsMenu );
@@ -424,7 +424,7 @@ void PlaylistWindow::init()
     layV->addWidget( statusbar );
 
     //The volume slider later becomes our FocusProxy, so all wheelEvents get redirected to it
-    m_toolbar->setFocusPolicy( TQ_WheelFocus );
+    m_toolbar->setFocusPolicy( TQWidget::WheelFocus );
     m_toolbar->setFlat( true );
     m_toolbar->setMovingEnabled( false );
     playlist->setMargin( 2 );
@@ -474,8 +474,8 @@ void PlaylistWindow::init()
         {
             addInstBrowserMacro( MediaBrowser, "MediaBrowser", i18n("Devices"), Amarok::icon( "device" ) )
             //to re-enable mediabrowser hiding, uncomment this:
-            //connect( MediaBrowser::instance(), TQT_SIGNAL( availabilityChanged( bool ) ),
-            //         this, TQT_SLOT( mbAvailabilityChanged( bool ) ) );
+            //connect( MediaBrowser::instance(), TQ_SIGNAL( availabilityChanged( bool ) ),
+            //         this, TQ_SLOT( mbAvailabilityChanged( bool ) ) );
             m_browsers->makeDropProxy( "MediaBrowser", MediaBrowser::queue() );
 
         }
@@ -484,17 +484,17 @@ void PlaylistWindow::init()
     }
     //</Browsers>
 
-    connect( Playlist::instance()->qscrollview(), TQT_SIGNAL( dynamicModeChanged( const DynamicMode* ) ),
-             PlaylistBrowser::instance(), TQT_SLOT( loadDynamicItems() ) );
+    connect( Playlist::instance()->qscrollview(), TQ_SIGNAL( dynamicModeChanged( const DynamicMode* ) ),
+             PlaylistBrowser::instance(), TQ_SLOT( loadDynamicItems() ) );
 
 
     tqApp->installEventFilter( this ); // keyboards shortcuts for the browsers
 
-    connect( playlist, TQT_SIGNAL( itemCountChanged(     int, int, int, int, int, int ) ),
-             statusbar,  TQT_SLOT( slotItemCountChanged( int, int, int, int, int, int ) ) );
-    connect( playlist, TQT_SIGNAL( queueChanged( const PLItemList &, const PLItemList & ) ),
-             statusbar,  TQT_SLOT( updateQueueLabel() ) );
-    connect( playlist, TQT_SIGNAL( aboutToClear() ), m_lineEdit, TQT_SLOT( clear() ) );
+    connect( playlist, TQ_SIGNAL( itemCountChanged(     int, int, int, int, int, int ) ),
+             statusbar,  TQ_SLOT( slotItemCountChanged( int, int, int, int, int, int ) ) );
+    connect( playlist, TQ_SIGNAL( queueChanged( const PLItemList &, const PLItemList & ) ),
+             statusbar,  TQ_SLOT( updateQueueLabel() ) );
+    connect( playlist, TQ_SIGNAL( aboutToClear() ), m_lineEdit, TQ_SLOT( clear() ) );
     Amarok::MessageQueue::instance()->sendMessages();
 }
 
@@ -506,7 +506,7 @@ void PlaylistWindow::slotSetFilter( const TQString &filter ) //SLOT
 void PlaylistWindow::slotEditFilter() //SLOT
 {
     EditFilterDialog *fd = new EditFilterDialog( this, true, m_lineEdit->text() );
-    connect( fd, TQT_SIGNAL(filterChanged(const TQString &)), TQT_SLOT(slotSetFilter(const TQString &)) );
+    connect( fd, TQ_SIGNAL(filterChanged(const TQString &)), TQ_SLOT(slotSetFilter(const TQString &)) );
     if( fd->exec() )
         m_lineEdit->setText( fd->filter() );
     delete fd;
@@ -554,7 +554,7 @@ void PlaylistWindow::createGUI()
          (*it)->unplug( m_toolbar );
 
     KXMLGUIBuilder builder( this );
-    KXMLGUIFactory factory( &builder, TQT_TQOBJECT(this) );
+    KXMLGUIFactory factory( &builder, this );
 
     //build Toolbar, plug actions
     factory.addClient( this );
@@ -578,7 +578,7 @@ void PlaylistWindow::createGUI()
     const TQStringList::ConstIterator last = list.fromLast();
     for( TQStringList::ConstIterator it = list.constBegin(); it != end; ++it )
     {
-        TDEToolBarButton* const button = static_cast<TDEToolBarButton*>( TQT_TQWIDGET(m_toolbar->child( (*it).latin1() )) );
+        TDEToolBarButton* const button = static_cast<TDEToolBarButton*>( m_toolbar->child( (*it).latin1() ) );
 
         if ( it == last ) {
             //if the user has no PlayerWindow, he MUST have the menu action plugged
@@ -589,7 +589,7 @@ void PlaylistWindow::createGUI()
 
         if ( button ) {
             button->modeChange();
-            button->setFocusPolicy( TQ_NoFocus );
+            button->setFocusPolicy( TQWidget::NoFocus );
         }
     }
 
@@ -639,7 +639,7 @@ bool PlaylistWindow::eventFilter( TQObject *o, TQEvent *e )
 
         //there are a few keypresses that we intercept
 
-        #define e TQT_TQKEYEVENT(e)
+        #define e static_cast<TQKeyEvent*>(e)
 
         if(( e->key() == Key_F2 ) && (e->state() == 0))
         {
@@ -682,7 +682,7 @@ bool PlaylistWindow::eventFilter( TQObject *o, TQEvent *e )
             }
         }
 
-        if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_lineEdit) ) //the search lineedit
+        if( o == m_lineEdit ) //the search lineedit
         {
             TQListViewItem *item;
             switch( e->key() )
@@ -753,7 +753,7 @@ bool PlaylistWindow::eventFilter( TQObject *o, TQEvent *e )
         //following are for Playlist::instance() only
         //we don't handle these in the playlist because often we manipulate the lineEdit too
 
-        if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(pl) )
+        if( o == pl )
         {
             if( pl->currentItem() && ( e->key() == Key_Up && pl->currentItem()->itemAbove() == 0 && !(e->state() & TQt::ShiftButton) ) )
             {
@@ -805,7 +805,7 @@ void PlaylistWindow::closeEvent( TQCloseEvent *e )
     Q_UNUSED( e );
     hide();
 #else
-    Amarok::genericEventHandler( TQT_TQWIDGET(this), TQT_TQEVENT(e) );
+    Amarok::genericEventHandler( this, e );
 #endif
 }
 
@@ -1079,7 +1079,7 @@ void PlaylistWindow::slotMenuActivated( int index ) //SLOT
     case ID_SHOW_PLAYERWINDOW:
         AmarokConfig::setShowPlayerWindow( !AmarokConfig::showPlayerWindow() );
         m_settingsMenu->changeItem( index, AmarokConfig::showPlayerWindow() ? i18n("Hide Player &Window") : i18n("Show Player &Window") );
-        TQTimer::singleShot( 0, kapp, TQT_SLOT( applySettings() ) );
+        TQTimer::singleShot( 0, kapp, TQ_SLOT( applySettings() ) );
         break;
     case Amarok::Menu::ID_RESCAN_COLLECTION:
         CollectionDB::instance()->startScan();
@@ -1200,17 +1200,17 @@ DynamicBar::DynamicBar(TQWidget* parent)
 // necessary because it has to be constructed before Playlist::instance(), but also connect to it
 void DynamicBar::init()
 {
-    connect(Playlist::instance()->qscrollview(), TQT_SIGNAL(dynamicModeChanged(const DynamicMode*)),
-                                                   TQT_SLOT(slotNewDynamicMode(const DynamicMode*)));
+    connect(Playlist::instance()->qscrollview(), TQ_SIGNAL(dynamicModeChanged(const DynamicMode*)),
+                                                   TQ_SLOT(slotNewDynamicMode(const DynamicMode*)));
 
     KPushButton* editDynamicButton = new KPushButton( i18n("Edit"), this, "DynamicModeEdit" );
-    connect( editDynamicButton, TQT_SIGNAL(clicked()), Playlist::instance()->qscrollview(), TQT_SLOT(editActiveDynamicMode()) );
+    connect( editDynamicButton, TQ_SIGNAL(clicked()), Playlist::instance()->qscrollview(), TQ_SLOT(editActiveDynamicMode()) );
 
     KPushButton* repopButton = new KPushButton( i18n("Repopulate"), this, "DynamicModeRepopulate" );
-    connect( repopButton, TQT_SIGNAL(clicked()), Playlist::instance()->qscrollview(), TQT_SLOT(repopulate()) );
+    connect( repopButton, TQ_SIGNAL(clicked()), Playlist::instance()->qscrollview(), TQ_SLOT(repopulate()) );
 
     KPushButton* disableButton = new KPushButton( i18n("Turn Off"), this, "DynamicModeDisable" );
-    connect( disableButton, TQT_SIGNAL(clicked()), Playlist::instance()->qscrollview(), TQT_SLOT(disableDynamicMode()) );
+    connect( disableButton, TQ_SIGNAL(clicked()), Playlist::instance()->qscrollview(), TQ_SLOT(disableDynamicMode()) );
 
     slotNewDynamicMode( Playlist::instance()->dynamicMode() );
 }
