@@ -16,7 +16,7 @@ class Track(object):
     __Q_SLOTS__ = FIELDS
 
     def __init__(self, **kwargs):
-        for key,value in kwargs.iteritems():
+        for key,value in kwargs.items():
             setattr(self, key, value)
 
 
