@@ -28,7 +28,7 @@ class Scrobbler : public TQObject, public EngineObserver
 {
     friend class MediaDevice;
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
@@ -115,7 +115,7 @@ class SubmitQueue : public TQPtrList<SubmitItem>
 
 class ScrobblerSubmitter : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
