@@ -81,10 +81,10 @@ Statistics::Statistics( TQWidget *parent, const char *name )
         m_lineEdit->setFrame( TQFrame::Sunken );
         m_lineEdit->installEventFilter( this ); //we intercept keyEvents
 
-        connect( button,     TQT_SIGNAL( clicked() )      , m_lineEdit  , TQT_SLOT( clear() ) );
-        connect( m_timer,    TQT_SIGNAL( timeout() )                    , TQT_SLOT( slotSetFilter() ) );
-        connect( m_lineEdit, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( slotSetFilterTimeout() ) );
-        connect( m_lineEdit, TQT_SIGNAL( returnPressed() )              , TQT_SLOT( slotSetFilter() ) );
+        connect( button,     TQ_SIGNAL( clicked() )      , m_lineEdit  , TQ_SLOT( clear() ) );
+        connect( m_timer,    TQ_SIGNAL( timeout() )                    , TQ_SLOT( slotSetFilter() ) );
+        connect( m_lineEdit, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SLOT( slotSetFilterTimeout() ) );
+        connect( m_lineEdit, TQ_SIGNAL( returnPressed() )              , TQ_SLOT( slotSetFilter() ) );
 
         TQToolTip::add( button, i18n( "Clear search field" ) );
     } //</Search LineEdit>
@@ -134,11 +134,11 @@ StatisticsList::StatisticsList( TQWidget *parent, const char *name )
     setAcceptDrops( false );
     setDragEnabled( true );
 
-    connect( this, TQT_SIGNAL( onItem( TQListViewItem*) ),  TQT_SLOT( startHover( TQListViewItem* ) ) );
-    connect( this, TQT_SIGNAL( onViewport() ),             TQT_SLOT( clearHover() ) );
-    connect( this, TQT_SIGNAL( clicked( TQListViewItem*) ), TQT_SLOT( itemClicked( TQListViewItem* ) ) );
-    connect( this, TQT_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint &, int ) ),
-             this,   TQT_SLOT( showContextMenu( TQListViewItem *, const TQPoint &, int )  ) );
+    connect( this, TQ_SIGNAL( onItem( TQListViewItem*) ),  TQ_SLOT( startHover( TQListViewItem* ) ) );
+    connect( this, TQ_SIGNAL( onViewport() ),             TQ_SLOT( clearHover() ) );
+    connect( this, TQ_SIGNAL( clicked( TQListViewItem*) ), TQ_SLOT( itemClicked( TQListViewItem* ) ) );
+    connect( this, TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint &, int ) ),
+             this,   TQ_SLOT( showContextMenu( TQListViewItem *, const TQPoint &, int )  ) );
 
     if( CollectionDB::instance()->isEmpty() )
         return;
@@ -694,7 +694,7 @@ StatisticsItem::StatisticsItem( TQString text, StatisticsList *parent, TDEListVi
 
     setText( 0, text );
 
-    connect( m_animTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAnimTimer() ) );
+    connect( m_animTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAnimTimer() ) );
 }
 
 void
