@@ -31,7 +31,7 @@ class StatisticsDetailedItem;
 
 class Statistics : public KDialogBase
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
@@ -54,7 +54,7 @@ class Statistics : public KDialogBase
 
 class StatisticsList : public TDEListView
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
@@ -93,7 +93,7 @@ class StatisticsList : public TDEListView
 /// The listview items which are the headers for the categories
 class StatisticsItem : public TQObject, public TDEListViewItem
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
