@@ -53,7 +53,7 @@ Amarok::TrayIcon::TrayIcon( TQWidget *playerWidget )
     //seems to be necessary
     TDEAction *quit = actionCollection()->action( "file_quit" );
     quit->disconnect();
-    connect( quit, TQT_SIGNAL(activated()), kapp, TQT_SLOT(quit()) );
+    connect( quit, TQ_SIGNAL(activated()), kapp, TQ_SLOT(quit()) );
 
     baseIcon     = KSystemTray::loadIcon( "amarok" );
     playOverlay  = Amarok::loadOverlay( "play", baseIcon.width() );
@@ -75,7 +75,7 @@ Amarok::TrayIcon::event( TQEvent *e )
         return Amarok::genericEventHandler( this, e );
 
     case TQEvent::Timer:
-        if( TQT_TQTIMEREVENT(e)->timerId() != blinkTimerID )
+        if( static_cast<TQTimerEvent*>(e)->timerId() != blinkTimerID )
             return KSystemTray::event( e );
 
         // if we're playing, blink icon
@@ -88,7 +88,7 @@ Amarok::TrayIcon::event( TQEvent *e )
         return true;
 
     case TQEvent::MouseButtonPress:
-        if( TQT_TQMOUSEEVENT(e)->button() == Qt::MidButton )
+        if( static_cast<TQMouseEvent*>(e)->button() == TQt::MidButton )
         {
             EngineController::instance()->playPause();
 
