@@ -72,7 +72,7 @@ int Amarok::ToolTip::s_hack = 0;
 void Amarok::ToolTip::add( ToolTipClient *client, TQWidget *parent ) //static
 {
     if( !s_manager )
-        s_manager = new Amarok::ToolTip::Manager( TQT_TQOBJECT(tqApp) );
+        s_manager = new Amarok::ToolTip::Manager( tqApp );
     new ToolTip( client, parent );
 }
 
@@ -123,7 +123,7 @@ Amarok::ToolTip::ToolTip( ToolTipClient *client, TQWidget *parent )
 {
     s_tooltips.append( this );
     TQFrame::setPalette( TQToolTip::palette() );
-    connect( &m_timer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( hideTip() ) );
+    connect( &m_timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( hideTip() ) );
 }
 
 Amarok::ToolTip::~ToolTip()
