@@ -36,7 +36,7 @@ public:
 
 class ToolTip: public TQFrame, public TQToolTip
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
