@@ -28,7 +28,7 @@ class TransferDialog;
 */
 class LIBAMAROK_EXPORT TransferDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
